/* gthumb "ClassicClips" style, v. 2010-06-11 */

/* Common */

body {
	background-color: #4B4B4B;
	color: white;
	font-size: 12px;
}

span.title {
	font-weight: bold;
	font-size: 150%;
}

span.page_index {
	font-weight: bold;
	font-size: small;
}

span.file_name {
	font-family: monospace;
}

span.copyright {
	font-size: small;
}

/* image.gthtml */

img.preview {
	border: 2px solid #fff;
}

img.thumbnail {
	border: 2px solid #fff;
}

div.preview_comment {
	text-align: justify;
}

span.comment {
	font-size: small;
}

div.properties {
	width: 80%;
}

span.property {
	font-size: small;
	font-weight: bold;
	color: #969696;
}

span.property_value {
	font-size: small;
	color: white;
}

/* index.gthtml */

td.td_index {
	color: #969696;
}

td.td_index span.image_dim {
	font-weight: bold;
}

/* links */

a:link { 
	font-weight: bold;
	text-decoration: none;
	color: white;
}

a:visited { 
	font-weight: bold;
	text-decoration: none;
	color: white;
}

a:hover {
	font-weight: bold;
	text-decoration: none;
	color: #FFD700;
}

.property-name {
	font-weight: bold;
	cursor: default;
}
