/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:ENUM, ENUM (../gthumb/gthumb/gth-marshal.list:1) */
extern
void gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* BOOLEAN:VOID (../gthumb/gthumb/gth-marshal.list:2) */
extern
void gth_marshal_BOOLEAN__VOID (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);

/* BOOLEAN:UINT, ENUM (../gthumb/gthumb/gth-marshal.list:3) */
extern
void gth_marshal_BOOLEAN__UINT_ENUM (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:BOOLEAN, POINTER (../gthumb/gthumb/gth-marshal.list:4) */
extern
void gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:BOXED, BOXED (../gthumb/gthumb/gth-marshal.list:5) */
extern
void gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* VOID:ENUM, ENUM (../gthumb/gthumb/gth-marshal.list:6) */
extern
void gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);

/* VOID:ENUM, INT (../gthumb/gthumb/gth-marshal.list:7) */
extern
void gth_marshal_VOID__ENUM_INT (GClosure     *closure,
                                 GValue       *return_value,
                                 guint         n_param_values,
                                 const GValue *param_values,
                                 gpointer      invocation_hint,
                                 gpointer      marshal_data);

/* VOID:INT, INT (../gthumb/gthumb/gth-marshal.list:8) */
extern
void gth_marshal_VOID__INT_INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);

/* VOID:OBJECT, BOOLEAN (../gthumb/gthumb/gth-marshal.list:9) */
extern
void gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:OBJECT, BOXED, ENUM (../gthumb/gthumb/gth-marshal.list:10) */
extern
void gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:OBJECT, BOXED, INT, ENUM (../gthumb/gthumb/gth-marshal.list:11) */
extern
void gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT, OBJECT (../gthumb/gthumb/gth-marshal.list:12) */
extern
void gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:OBJECT, OBJECT, BOOLEAN (../gthumb/gthumb/gth-marshal.list:13) */
extern
void gth_marshal_VOID__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT, POINTER (../gthumb/gthumb/gth-marshal.list:14) */
extern
void gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:OBJECT, STRING (../gthumb/gthumb/gth-marshal.list:15) */
extern
void gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:OBJECT, UINT (../gthumb/gthumb/gth-marshal.list:16) */
extern
void gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* VOID:POINTER, POINTER (../gthumb/gthumb/gth-marshal.list:17) */
extern
void gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:STRING, STRING, BOOLEAN, DOUBLE (../gthumb/gthumb/gth-marshal.list:18) */
extern
void gth_marshal_VOID__STRING_STRING_BOOLEAN_DOUBLE (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);


G_END_DECLS
